camelot.camelot.view.controls.modeltree

Package camelot :: Package camelot :: Package view :: Package controls :: Module modeltree |
[hide private]
[frames] | no frames]

# Module modeltree

source code

custom tree and tree-items widgets

Classes | [hide private]
| ModelItem Custom tree item widget
| ModelTree Custom tree widget

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.controls.modeltree')`
| QT_MAJOR_VERSION = `float('.'.join(str(QtCore.QT_VERSION_STR).s`...``

Variables Details | [hide private]

  ### QT_MAJOR_VERSION Value:
      float('.'.join(str(QtCore.QT_VERSION_STR).split('.') [0: 2]))